==> loki-0.3.8.tgz: package/src/commands/test/index.js <==
const pickBy = require('ramda/src/pickBy');
const uniq = require('ramda/src/uniq');
const minimist = require('minimist');
const { warn, error, info } = require('../../console');
const getConfig = require('../../config');
const parseOptions = require('./parse-options');
const runTests = require('./run-tests');
const ensureInstalled = require('../../ensure-installed');
const { ReferenceImageError } = require('../../errors');

const escapeRegExp = str => str.replace(/[-[\]/{}()*+?.\\^$|]/g, '\\$&');

const escapeShell = str => `"${str.replace(/(["\t\n\r$`\\])/g, '\\$1')}"`;

const argObjectToString = args =>
  Object.keys(args)
    .filter(arg => args[arg] !== false && typeof args[arg] !== 'undefined')
    .map(arg => {
      const flag = arg.length === 1 ? `-${arg}` : `--${arg}`;
      if (typeof args[arg] === 'boolean') {
        return flag;
      }
      return `${flag}=${escapeShell(String(args[arg]))}`;
    })
    .join(' ');

const getUpdateCommand = (errors, argv) => {
  const stories = uniq(errors.map(e => `${e.kind} ${e.story}`));
  const tooManyToFilter = stories.length > 10;

  const args = Object.assign(
    {
      'configuration-filter': argv._[1],
    },
    pickBy((value, key) => {
      switch (key) {
        case '_':
        case 'require-reference': {
          return false;
        }
        case 'filter-stories':
        case 'skip-stories': {
          return tooManyToFilter;
        }
        default: {
          return true;
        }
      }
    }, argv),
    tooManyToFilter
      ? {}
      : {
          'filter-stories': `^${stories.map(escapeRegExp).join('|')}$`,
        }
  );
  return `yarn loki update -- ${argObjectToString(args)}`;
};

async function test(args) {
  const argv = minimist(args);
  const config = getConfig();
  const options = parseOptions(args, config);

  if (options.diffingEngine === 'gm') {
    ensureInstalled('gm');
  }

  const targetFilter = new RegExp(argv['target-filter']);
  const configurationFilter = new RegExp(
    argv['configuration-filter'] || argv._[1]
  );
  const matchesFilters = ({ target }, name) =>
    targetFilter.test(target) && configurationFilter.test(name);

  const configurations = pickBy(matchesFilters, config.configurations);

  if (Object.keys(configurations).length === 0) {
    warn('No matching configurations');
    process.exit(0);
  }

  try {
    await runTests(configurations, options);
  } catch (err) {
    if (err.name === 'ListrError') {
      const imageErrors = err.errors.filter(
        e => e instanceof ReferenceImageError
      );
      if (imageErrors.length !== 0) {
        error('Visual tests failed');
        info('You can update the reference files with:');
        info(getUpdateCommand(imageErrors, argv));
      } else {
        error('Some visual tests failed to run');
      }
      process.exit(1);
    }
    throw err;
  }
}

module.exports = test;

==> loki-0.9.1.tgz: package/src/commands/test/index.js <==
const pickBy = require('ramda/src/pickBy');
const uniq = require('ramda/src/uniq');
const minimist = require('minimist');
const { warn, error, info } = require('../../console');
const getConfig = require('../../config');
const parseOptions = require('./parse-options');
const runTests = require('./run-tests');
const { ensureDependencyAvailable } = require('../../dependency-detection');
const { ReferenceImageError } = require('../../errors');
const buildCommand = require('../../build-command');

const escapeRegExp = str => str.replace(/[-[\]/{}()*+?.\\^$|]/g, '\\$&');

const getUpdateCommand = (errors, args) => {
  const argv = minimist(args);
  const stories = uniq(errors.map(e => `${e.kind} ${e.story}`));
  const storiesFilter = `^${stories.map(escapeRegExp).join('|')}$`;
  const tooManyToFilter = stories.length > 10;

  const argObject = Object.assign(
    {
      configurationFilter: argv._[1],
      storiesFilter: !tooManyToFilter && storiesFilter,
    },
    pickBy((value, key) => {
      switch (key) {
        case '_':
        case 'requireReference': {
          return false;
        }
        case 'storiesFilter':
        case 'skipStories': {
          return tooManyToFilter;
        }
        default: {
          return true;
        }
      }
    }, argv)
  );

  return buildCommand('update', argObject);
};

async function test(args) {
  const config = getConfig();
  const options = parseOptions(args, config);

  if (options.diffingEngine === 'gm') {
    ensureDependencyAvailable('gm');
  }

  const targetFilter = new RegExp(options.targetFilter);
  const configurationFilter = new RegExp(options.configurationFilter);
  const matchesFilters = ({ target }, name) =>
    targetFilter.test(target) && configurationFilter.test(name);

  const configurations = pickBy(matchesFilters, config.configurations);

  if (Object.keys(configurations).length === 0) {
    warn('No matching configurations');
    process.exit(0);
  }

  try {
    await runTests(configurations, options);
  } catch (err) {
    if (err.name === 'ListrError') {
      const imageErrors = err.errors.filter(
        e => e instanceof ReferenceImageError
      );
      if (imageErrors.length !== 0) {
        error('Visual tests failed');
        info('You can update the reference files with:');
        info(getUpdateCommand(imageErrors, args));
      } else {
        error('Some visual tests failed to run');
      }
      process.exit(1);
    }
    throw err;
  }
}

module.exports = test;
